import * as events from '@aws-cdk/aws-events';
import * as r53 from '@aws-cdk/aws-route53';
import * as s3 from '@aws-cdk/aws-s3';
import * as cdk from '@aws-cdk/core';
/**
 * @stability stable
 */
export interface CertbotOptions {
    /**
     * the domain must host on route53 like example.com.
     *
     * @stability stable
     * @example
     *
     * - *.example.com
     */
    readonly domainName: string;
    /**
     * Email address for important account notifications.
     *
     * @stability stable
     */
    readonly email: string;
}
/**
 * @stability stable
 */
export interface CertbotDnsRoute53JobProps {
    /**
     * run the Job with defined schedule.
     *
     * @default - no shedule
     * @stability stable
     */
    readonly schedule?: events.Schedule;
    /**
     * The S3 bucket to store certificate.
     *
     * @stability stable
     */
    readonly destinationBucket: s3.IBucket;
    /**
     * The HostZone on route53 to dns-01 challenge.
     *
     * @stability stable
     */
    readonly zone: r53.IHostedZone;
    /**
     * certbot cmd options.
     *
     * @stability stable
     */
    readonly certbotOptions: CertbotOptions;
}
/**
 * @stability stable
 */
export declare class CertbotDnsRoute53Job extends cdk.Construct {
    /**
     * @stability stable
     */
    constructor(scope: cdk.Construct, id: string, props: CertbotDnsRoute53JobProps);
}
